#ifndef dplyr_tools_tools_H
#define dplyr_tools_tools_H

#include <tools/DotsOf.h>
#include <tools/Call.h>
#include <tools/hash.h>
#include <tools/delete_all.h>
#include <tools/ListOf.h>
#include <tools/collapse.h>
#include <tools/get_single_class.h>
#include <tools/SlicingIndex.h>
#include <tools/ShrinkableVector.h>
#include <tools/wrap_subset.h>
#include <tools/get_all_second.h>
#include <tools/JoinColumnSuffixer.h>
#include <tools/DataDots.h>

#endif
